# coding: utf-8
import os
import csv
import logging

logger = logging.getLogger(__name__)

_CURRENT_DIR = os.path.abspath(os.path.dirname(__file__))
JOURNALS = {}

CURRENT_METRICS = '2017'

with open(_CURRENT_DIR + '/data/google_metrics_h5m5.csv', 'r') as metrics:
    spamreader = csv.reader(metrics, delimiter=',', quotechar='"')
    for line in spamreader:
        issn = line[0].upper()
        year = line[1]
        h5 = line[3]
        m5 = line[4]
        url = line[5]
        j = JOURNALS.setdefault(issn, {})

        JOURNALS[issn][year] = {
            'h5': h5,
            'm5': m5,
            'url': url,
            'year': year
        }


def get_metrics(issn, year=None):
    """
        issn: journal issn,
        year: indicator year
    """

    data = JOURNALS.get(issn, None)

    if data and year:
        return data.get(year, None)

    return data


def get_current_metrics(issn):
    """
        This method will retrive the current H5M5 metric. It means the last year
        the H5M5 indicators were produced by Google Scholar.
        issn: journal issn
    """
    return get_metrics(issn, CURRENT_METRICS)


def get(issn, year=None):
    from warnings import warn
    warn("method get is deprecated, use get_metrics instead.")

    return get_metrics(issn, year)



#!/usr/bin/env python
from setuptools import setup, find_packages

install_requires = []

tests_require = []

setup(
    name="scieloh5m5",
    version="1.11.0",
    description="Library to delivery H5 M5 Google Scholar metrics for the SciELO Journals",
    author="SciELO",
    author_email="scielo-dev@googlegroups.com",
    maintainer="Fabio Batalha",
    maintainer_email="fabio.batalha@scielo.org",
    url="http://github.com/scieloorg/processing",
    packages=find_packages(),
    include_package_data=True,
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 2.7",
    ],
    dependency_links=[],
    tests_require=tests_require,
    test_suite='tests',
    install_requires=install_requires
)



# coding: utf-8
import unittest

from scieloh5m5 import h5m5


class H5M5Test(unittest.TestCase):

    def test_load_issn(self):

        result = h5m5.get_metrics('0103-3352')

        expected = {
            u'2017': {
                'h5': '13',
                'm5': '18',
                'url': 'http://scholar.google.com/citations?view_op=list_hcore&venue=7e-4gBNaGSMJ.2017&hl=en',
                'year': '2017'
            },
            u'2016': {
                'h5': u'12',
                'm5': u'17',
                'url': u'http://scholar.google.com/citations?view_op=list_hcore&venue=Q_f-804K9OAJ.2016&hl=en',
                'year': u'2016'
            },
            u'2015': {
                'm5': u'16',
                'url': u'http://scholar.google.com/citations?view_op=list_hcore&venue=EqPlmpMQjygJ.2015&hl=pt-BR',
                'h5': u'10',
                'year': u'2015'
            },
            u'2014': {
                'm5': u'12',
                'url': u'http://scholar.google.com/citations?view_op=list_hcore&venue=EqPlmpMQjygJ.2014&hl=pt-br',
                'h5': u'9',
                'year': u'2014'
            },
            u'2013': {
                'm5': u'8',
                'url': u'http://scholar.google.com/citations?view_op=list_hcore&venue=EqPlmpMQjygJ.2013&hl=pt-br',
                'h5': u'7',
                'year': u'2013'
            }
        }

        self.maxDiff = None
        self.assertEqual(expected, result)

    def test_load_issn_year(self):

        result = h5m5.get_metrics('0103-3352', '2015')

        expected = {
            'h5': u'10',
            'm5': u'16',
            'url': u'http://scholar.google.com/citations?view_op=list_hcore&venue=EqPlmpMQjygJ.2015&hl=pt-BR',
            'year': u'2015'
        }

        self.assertEqual(expected, result)

    def test_load_issn_year_not_available_year(self):

        result = h5m5.get_metrics('0103-3352', 'XXXX')

        expected = None

        self.assertEqual(expected, result)

    def test_load_issn_year_not_available_issn(self):

        result = h5m5.get_metrics('0103-XXXX')

        expected = None

        self.assertEqual(expected, result)
